==> 2.2.0-dev1.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraService.java <==
package com.netmera.netmera_flutter_sdk;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodChannel;

/**
 * Copyright (c) 2023 Netmera Research.
 * @author Initial Code
 */

public class FNetmeraService {
    private static MethodChannel _channel;
    private static boolean initialized = false;
    private static final List<Bundle> _messageQueue = new ArrayList<>();

    /**
     * It is called when the Dart callbacks are ready and it creates Netmera Flutter Method Channel.
     *
     * @param binding FlutterPluginBinding.
     * @param result FlutterMethodChannel result
     */
    static void initializeService(FlutterPlugin.FlutterPluginBinding binding, MethodChannel.Result result) {
        _channel = new MethodChannel(binding.getBinaryMessenger(), "netmera_flutter_sdk");
        initialized = true;
        FNetmeraService.handleMethodCall();
        result.success(true);
    }

    /**
     * Sends messages to the Dart side.
     *
     * @param bundle Message object bundle.
     */
    static void sendMessage(Bundle bundle) {
        String action = bundle.getString("action");
        Map<String, Object> message = FNetmeraUtils.convertBundleToMap(bundle.getBundle("message"));
        new Handler(Looper.getMainLooper()).post(() -> _channel.invokeMethod(action, message));
    }

    /**
     * Called when the Method Channel is ready.
     * Executes pending tasks and removes them from the queue.
     */
    static void handleMethodCall() {
        synchronized (_messageQueue) {
            while (!_messageQueue.isEmpty()) {
                Bundle message = _messageQueue.get(0);
                _messageQueue.remove(0);
                FNetmeraService.sendMessage(message);
            }
        }
    }

    /**
     * When a task is requested to execute, it adds the task to the queue if the Method Channel
     * is not ready. If the channel is ready, it will send directly to the Dart side.
     *
     * @param action Name of action
     * @param message Object to execute
     */
    static void handleWork(String action, Bundle message) {
        synchronized (_messageQueue) {
            Bundle bundle = new Bundle();
            bundle.putString("action", action);
            bundle.putBundle("message", message);
            if (initialized) {
                FNetmeraService.sendMessage(bundle);
            } else {
                _messageQueue.add(bundle);
            }
        }
    }

}

==> 2.2.1.tar.gz: android/src/main/java/com/netmera/netmera_flutter_sdk/FNetmeraService.java <==
package com.netmera.netmera_flutter_sdk;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodChannel;

/**
 * Copyright (c) 2023 Netmera Research.
 * @author Initial Code
 */

public class FNetmeraService {
    private static MethodChannel _channel;
    private static boolean initialized = false;
    private static final List<Bundle> _messageQueue = new ArrayList<>();

    /**
     * It is called when the Dart callbacks are ready and it creates Netmera Flutter Method Channel.
     *
     * @param binding FlutterPluginBinding.
     * @param result FlutterMethodChannel result
     */
    static void initializeService(FlutterPlugin.FlutterPluginBinding binding, MethodChannel.Result result) {
        _channel = new MethodChannel(binding.getBinaryMessenger(), "netmera_flutter_sdk");
        initialized = true;
        FNetmeraService.handleMethodCall();
        result.success(true);
    }

    /**
     * Sends messages to the Dart side.
     *
     * @param bundle Message object bundle.
     */
    static void sendMessage(Bundle bundle) {
        String action = bundle.getString("action");
        Map<String, Object> message = FNetmeraUtils.convertBundleToMap(bundle.getBundle("message"));
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                _channel.invokeMethod(action, message);
            }
        });
    }

    /**
     * Called when the Method Channel is ready.
     * Executes pending tasks and removes them from the queue.
     */
    static void handleMethodCall() {
        synchronized (_messageQueue) {
            while (!_messageQueue.isEmpty()) {
                Bundle message = _messageQueue.get(0);
                _messageQueue.remove(0);
                FNetmeraService.sendMessage(message);
            }
        }
    }

    /**
     * When a task is requested to execute, it adds the task to the queue if the Method Channel
     * is not ready. If the channel is ready, it will send directly to the Dart side.
     *
     * @param action Name of action
     * @param message Object to execute
     */
    static void handleWork(String action, Bundle message) {
        synchronized (_messageQueue) {
            Bundle bundle = new Bundle();
            bundle.putString("action", action);
            bundle.putBundle("message", message);
            if (initialized) {
                FNetmeraService.sendMessage(bundle);
            } else {
                _messageQueue.add(bundle);
            }
        }
    }

}
